<?php

namespace QUI\RabbitMQServer\Interface;

use DateTimeImmutable;
use PCSG\Tasks\WorkerTask;
use PCSG\Tasks\WorkerTaskDataInterface;
use QUI\QueueManager\QueueJob;
use QUI\QueueManager\QueueJobUUID;

interface TaskSchedulerInterface
{
    /**
     * Create a queue job for a (QUIQQER-independent) task worker and queue it.
     *
     * @param WorkerTaskDataInterface $taskData
     * @param string $logLevel - PSR-3 log level
     * @param DateTimeImmutable|null $earliestQueueDate (optional) - If omitted, the job will be queued at the earliest
     * @param int|null $priority (optional) - default: 1 (standard priority)
     * @return QueueJobUUID - Worker task / queue job UUID
     */
    public function queueWorkerTask(
        WorkerTaskDataInterface $taskData,
        string $logLevel,
        ?DateTimeImmutable $earliestQueueDate = null,
        ?int $priority = 1
    ): string;

    /**
     * @param WorkerTask $workerTask
     * @return QueueJob
     */
    public function createQueueJobFromWorkerTask(WorkerTask $workerTask): QueueJob;
}
