<?php

namespace QUI\RabbitMQServer\REST;

use Psr\Http\Message\ResponseInterface as ResponseInterface;
use QUI\RabbitMQServer\REST\Exception\ServerErrorException;
use Symfony\Component\HttpFoundation\Response as SymfonyResponse;

use function json_encode;

class Utils
{
    /**
     * Set data to successful response and return it.
     *
     * @param ResponseInterface $response
     * @param string|array $msg
     * @param int $statusCode (optional) - [default: 200]
     * @return ResponseInterface
     */
    public static function buildSuccessResponse(
        ResponseInterface $response,
        string|array $msg,
        int $statusCode = SymfonyResponse::HTTP_OK
    ): ResponseInterface {
        $body = [
            'msg' => $msg,
            'error' => false
        ];

        $response->getBody()->write(json_encode($body));

        return $response
            ->withHeader('Content-Type', 'application/json')
            ->withStatus($statusCode);
    }

    /**
     * Set data to error response and return it.
     *
     * @param ResponseInterface $response
     * @param string|array $msg
     * @param int $errorCode
     * @param int $statusCode (optional) - [default: 200]
     * @return ResponseInterface
     */
    public static function buildErrorResponse(
        ResponseInterface $response,
        string|array $msg,
        int $errorCode,
        int $statusCode = SymfonyResponse::HTTP_INTERNAL_SERVER_ERROR,
    ): ResponseInterface {
        $body = [
            'msg' => $msg,
            'error' => true,
            'error_code' => $errorCode
        ];

        $response->getBody()->write(json_encode($body));

        return $response
            ->withHeader('Content-Type', 'application/json')
            ->withStatus($statusCode);
    }

    /**
     * @return void
     * @throws ServerErrorException
     */
    public static function throwGeneralServerErrorException(): void
    {
        throw new ServerErrorException(
            "An unexpected server error occurred. Please try again or contact an administrator."
        );
    }
}
